@@ -1,21 +1,19 @@
 import numpy as np
 import pandas as pd
+from pydataset import data
 
 
 #make funtion to return list of all pydataset datasets
 def lista_datasets():
-    import pydataset
-    return(pydataset.data)
+    return(data())
 
 #make funtion to print documentation of specific dataset of pydataset
 def documentazione_dataset(nome_dataset):
-    import pydataset
-    print(pydataset.data(nome_dataset).__doc__)
+    print(data(nome_dataset).__doc__)
 
 #make funtion to return dataframe of secific dataset of pydataset
 def importa_dataset(nome_dataset):
-    import pydataset
-    return(pydataset.data(nome_dataset))
+    return(data(nome_dataset))
 
 #make function to return list of columns in dataframe
 def lista_colonne(df):
